@@ -6,14 +6,13 @@ async def test_websocket():
     scope = {
         "type": "websocket",
         "subprotocols": ["stomp"],
+        "headers": [],
     }
 
     receive = AsgiReceiveInspector()
     send = WebSocketSendInspector()
 
     request = Request(scope, receive, send)
-    ws = request.websocket
-    assert ws is not None
 
     receive.send(
         {
@@ -21,16 +20,20 @@ async def test_websocket():
         }
     )
 
-    await ws.accept(subprotocol="stomp")
-
+    await request.websocket.accept(subprotocol="stomp")
     assert send.subprotocol == "stomp"
 
 
 async def test_non_websocket_request():
-    scope = {
-        "type": "http",
-    }
+    scope = {"type": "http", "headers": []}
 
-    request = Request(scope, None, None)
-    ws = request.websocket
-    assert ws is None
+    async def asgi_receive():
+        return {
+            "type": "websocket.connect",
+        }
+
+    async def asgi_send(_message):
+        pass
+
+    request = Request(scope, asgi_receive, asgi_send)
+    assert request.websocket is None
